@@ -172,7 +172,7 @@ def differential_test(name: str, group_a: List[str], group_b: List[str], min_sam
     if group_test:
         counts_a = _counts_a[bad]; counts_b = _counts_b[bad]; counts = _counts[bad]
         counts_a = counts_a[counts_a[:, 0] + counts_a[:, 1] < max_cover_group_test]
-        counts_b = counts_a[counts_b[:, 0] + counts_b[:, 1] < max_cover_group_test]
+        counts_b = counts_b[counts_b[:, 0] + counts_b[:, 1] < max_cover_group_test]
         counts = counts[counts[:, 0] + counts[:, 1] < max_cover_group_test]
         (whole_ref, whole_alt), _ = difftest(('all', counts_a, counts_b, counts), inst_params, params, skip_failures=False, bad=bad)
         df_whole = pd.DataFrame([list(whole_ref) + list(whole_alt)], columns=cols)
